@@ -1,5 +1,5 @@
-# $Revision: 2.3 $
-# $Id: ISBN13.pm,v 2.3 2007/03/14 07:31:26 comdog Exp $
+# $Revision: 2.6 $
+# $Id: ISBN13.pm,v 2.6 2007/09/01 09:08:27 comdog Exp $
 package Business::ISBN13;
 use strict;
 use base qw(Business::ISBN);
@@ -24,15 +24,15 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-($VERSION)   = q$Revision: 2.3 $ =~ m/(\d+\.\d+)\s*$/;
+($VERSION)   = q$Revision: 2.6 $ =~ m/(\d+\.\d+)\s*$/;
 
-sub _max_length { 10 }
+sub _max_length { 13 }
 
 sub _set_type     { $_[0]->{type} = 'ISBN13' }
 
 sub _parse_prefix 
 	{ 
-	( $_[0]->isbn =~ /\A(\d\d\d)(.{10})\z/g )[0];
+	( $_[0]->isbn =~ /\A(97[89])(.{10})\z/g )[0];
 	}
 
 sub _set_prefix   
@@ -53,6 +53,8 @@ sub _hyphen_positions
 	]
 	}
 
+sub group { 'Bookland' }
+
 sub as_isbn10
 	{
 	my $self = shift;
